Function to determine communities in a network using clique percolation method (Palla et al., 2005). Communities are created based on cliques. Cliques are subsets of a network that can be considered complete (sub)networks. The size of the cliques to be used to community detection is part of the input of the function.
Usage
clique_community_names(g, k = 3)
Value
a dataframe with node names and community name. The community is named as CPM_Kk_number_of_community with k replaced by the value of k.
Arguments
g
network object (igraph)
k
clique size to be used. The default is set to smallest possible size (3)
Author
Angelo Salatino
Ronald Visser
References
Palla, G., Derényi, I., Farkas, I., & Vicsek, T. (2005). Uncovering the overlapping community structure of complex networks in nature and society. Nature, 435(7043), 814-818.
Code adapted from source: https://github.com/angelosalatino/CliquePercolationMethod-R/blob/master/clique.community.R