Learn R Programming

dendroNetwork (version 0.5.5)

cyto_clean_styles: Cleaning nearly all styles in cytoscape session and import simple styles.

Description

Cleaning nearly all styles in cytoscape session and import simple styles.

Usage

cyto_clean_styles()

Arguments

Value

Cytoscape cleaned of styles and only styles with white and grey nodes.

Examples

Run this code
if (FALSE) {
cyto_clean_styles()
}

Run the code above in your browser using DataLab