dendroNetwork: Create Networks of Dendrochronological Series using Pairwise Similarity
Source:R/dendroNetwork-package.R
dendroNetwork-package.RdCreating dendrochronological networks based on the similarity between tree-ring series or chronologies. The package includes various functions to compare tree-ring curves building upon the 'dplR' package. The networks can be used to visualise and understand the relations between tree-ring curves. These networks are also very useful to estimate the provenance of wood as described in Visser (2021) doi:10.5334/jcaa.79 or wood-use within a structure/context/site as described in Visser and Vorst (2022) doi:10.1163/27723194-bja10014 .
Author
Maintainer: Ronald Visser r.m.visser@saxion.nl (ORCID)
Other contributors:
Angelino Salentino (ORCID) [contributor]
Andy Bunn (ORCID) [contributor]
Kaija Gahm (Kaija Gahm reviewed the package for rOpenSci, see https://github.com/ropensci/software-review/issues/627#issuecomment-1993235710) [reviewer]
Zachary Gajewski (Zachary Gajewski reviewed the package for rOpenSci, see https://github.com/ropensci/software-review/issues/627#issuecomment-2037644081) [reviewer]