powered by
Cleaning nearly all styles in cytoscape session and import simple styles.
cyto_clean_styles()
Cytoscape cleaned of styles and only styles with white and grey nodes.
if (FALSE) { cyto_clean_styles() }
Run the code above in your browser using DataLab